# xshap

[![License](https://img.shields.io/github/license/Priyanshu-server/xshap)](https://github.com/Priyanshu-server/xshap/blob/main/LICENSE.txt)
[![PyPI](https://img.shields.io/pypi/v/xshap)](https://pypi.org/project/xshap/)
[![Python Version](https://img.shields.io/pypi/pyversions/xshap)](https://pypi.org/project/xshap/)

**xshap** is a Python package created as a wrapper for the original Shap package to simplify the learning process.

## Installation

You can install **xshap** via pip:

```bash
pip install xshap
```
## Enjoy !